<?php
/**
 * Project:
 * DZIRCMS Content Management System
 *
 * Description:
 * DZIRCMS Module class
 *
 * Requirements:
 * PHP 7.0
 * 
 *
 * @package    DZIRCMS Plugin Manager
 * @version    1.0.0
 * @author     René Mansveld
 * @copyright  Spider IT Deutschland
 * @license    MIT
 * @link       https://www.dzir.org/cms/
 * @link       https://www.spider-it.de/
 *
 * {@internal 
 *   created 2023-11-11
 * }}
 */

if (!defined('CON_FRAMEWORK')) {
    die('Illegal call');
}

class ModuleInfo {
    
    protected $plugin = '';

    protected $name = '';
    
    protected $info;
    
    /**
     * Construct
     *
     * @param string $pluginName
     * @param string optional $moduleName
     */
    public function __construct($pluginName, $moduleName = '') {
        $this->plugin = $pluginName;
        if (strlen($moduleName)) {
            $this->moduleName($moduleName);
        }
    }
    
    /**
     * loader function moduleName
     *
     * @param [type] $moduleName
     * @return void
     */
    public function moduleName($moduleName) {
        $this->name = $moduleName;
        $this->_loadModuleInfo();
    }
    
    public function checkTags($sFilter) {
        $aTags = array();
        if ($this->info != '') {
            if (count((array) $this->info->general->tags)) {
                foreach ($this->info->general->tags->tag as $tag) {
                    $aTags[] = (string) $tag;
                }
            }
        }
        $aFilter = explode(',', $sFilter);
        foreach ($aFilter as $sTag) {
            if (in_array(strtolower($sTag), $aTags)) {
                return true;
            }
        }
        return false;
    }
    
    /**
     * function getInfo()
     * 
     * get's the info from the module's module.xml
     *
     * @return array/false
     */
    public function getInfo() {
        if ($this->info != '') {
            $aDescriptions = array();
            if (count((array) $this->info->general->descriptions)) {
                foreach ($this->info->general->descriptions->description as $desc) {
                    $aDescriptions[(string) $desc['lang']] = (string) $desc;
                }
            }
            $aTags = array();
            if (count((array) $this->info->general->tags)) {
                foreach ($this->info->general->tags->tag as $tag) {
                    if (isset($tag['lang'])) {
                        $aTags[(string) $tag['lang']][] = (string) $tag;
                    }
                    else {
                        $aTags[] = (string) $tag;
                    }
                }
            }
            $dzircms = (string) $this->info->requirements->dzircms;
            if (strlen($dzircms) == 0) {
                $dzircms = (string) $this->info->requirements->drugcms;
            }
            return array('Name' => (string) $this->info->general->name, 'Description' => $aDescriptions, 'Tags' => $aTags, 'Author' => (string) $this->info->general->author, 'Version' => (string) $this->info->general->version, 'Date' => (string) $this->info->general->date, 'Copyright' => (string) $this->info->general->copyright, 'Requirements' => array('php' => (string) $this->info->requirements->php, 'dzircms' => $dzircms));
        }
        else {
            return false;
        }
    }
    
    /**
     * function getInstallInfo()
     * 
     * Gets the installation and translation files from the info
     *
     * @return array/false
     */
    public function getInstallInfo() {
        if ($this->info != '') {
            $sFile = '';
            $aLangs = array();
            foreach ($this->info->files->file as $file) {
                if (isset($file['lang'])) {
                    $aLangs[(string) $file['lang']] = (string) $file;
                }
                else {
                    $sFile = (string) $file;
                }
            }
            
            return array('module' => $sFile, 'languages' => $aLangs);
        }
        else {
            return false;
        }
    }
    
    /**
     * function getAdditionalFoldersAndFiles()
     * 
     * Gets all additional folders and files used by the module
     *
     * @return array
     */
    public function getAdditionalFoldersAndFiles() {
        global $cfg;
        
        $sPath = $cfg['path']['contenido'] . 'plugins/' . $this->plugin . '/modules/' . $this->name;
        $aFoldersAndFiles = $this->_getFoldersAndFilesRecursively($sPath);
        for ($i = (count($aFoldersAndFiles) - 1); $i >= 0; $i --) {
            if (substr($aFoldersAndFiles[$i], -4) == '.xml') {
                unset($aFoldersAndFiles[$i]);
            }
        }
        return $aFoldersAndFiles;
    }
    
    /**
     * function getAdditionalTablesToDelete()
     * 
     * Gets thetables created by the module which should
     * be deleted on deleting the module if not used by
     * other clients
     *
     * @return array/false
     */
    public function getAdditionalTablesToDelete() {
        if ($this->info != '') {
            $aDbTables = array();
            if (count((array) $this->info->dbtables)) {
                foreach ($this->info->dbtables->dbtable as $dbtable) {
                    $aDbTables[] = (string) $dbtable;
                }
                return $aDbTables;
            }
            else {
                return false;
            }
        }
        else {
            return false;
        }
    }
    
    /**
     * function _loadModuleInfo()
     * 
     * Reads the info from the module's module.xml file
     *
     * @return void
     */
    protected function _loadModuleInfo() {
        global $cfg;
        
        if (strlen($this->name)) {
            $this->info = simplexml_load_file($cfg['path']['contenido'] . 'plugins/' . $this->plugin . '/modules/' . $this->name . '/module.xml', 'SimpleXMLElement', LIBXML_NOCDATA);
        }
        else {
            $this->info = '';
        }
    }
}
?>